@@ -6,7 +6,7 @@ from subprocess import Popen, PIPE, STDOUT
 from ringbuffer import RingBuffer
 from exceptions import Timeout, EOF, UnexpectedExit
 
-__version__ = '0.4.2'
+__version__ = '0.4.3'
 
 
 class What(Popen):
@@ -53,10 +53,15 @@ class What(Popen):
         try:
             while 1:
                 passed = time() - start
-                line = self.queue.get(timeout=timeout - passed)
+                get_timeout = timeout - passed
+                if get_timeout < 0:
+                    raise Timeout(self, string)
+
+                line = self.queue.get(timeout=get_timeout)
                 if line is EOF:
                     self.wait()
                     raise EOF(self, string)
+
                 if string in line:
                     return line
         except Empty:
